# Needed when building new python3 version
%bcond_with bootstrap

Name:           pyproject-rpm-macros
Summary:        RPM macros for PEP 517 Python packages
# SPDX
License:        MIT
Group:          Development/Python

%bcond_with tests
# pytest-xdist and tox are not desired in RHEL
%bcond_without pytest_xdist
%bcond_without tox_tests

# The idea is to follow the spirit of semver
# Given version X.Y.Z:
#   Increment X and reset Y.Z when there is a *major* incompatibility
#   Increment Y and reset Z when new macros or features are added
#   Increment Z when this is a bugfix or a cosmetic change
# Dropping support for EOL Fedoras is *not* considered a breaking change
Version:        1.16.3
Release:        %mkrel 4

# Macro files
Source001:      macros.pyproject
Source002:      macros.aaa-pyproject-srpm

# Mageia patches
# /!\ WARNING
# NEVER REMOVE THEM! IF REMOVED IT WILL BREAK ALL THE STACK!

Patch000:       no-boolean-deps.patch
Patch001:       loosen-build-deps.patch
# Until someone figures out why the order is different
Patch002:       tests.patch

# Implementation files
Source101:      pyproject_buildrequires.py
Source102:      pyproject_save_files.py
Source103:      pyproject_convert.py
Source104:      pyproject_preprocess_record.py
Source105:      pyproject_construct_toxenv.py
Source106:      pyproject_requirements_txt.py
Source107:      pyproject_wheel.py

# Tests
Source201:      test_pyproject_buildrequires.py
Source202:      test_pyproject_save_files.py
Source203:      test_pyproject_requirements_txt.py
Source204:      compare_mandata.py

# Test data
Source301:      pyproject_buildrequires_testcases.yaml
Source302:      pyproject_save_files_test_data.yaml
Source303:      test_RECORD

# Metadata
Source901:      README.md
Source902:      LICENSE

URL:            https://src.fedoraproject.org/rpms/pyproject-rpm-macros

BuildArch:      noarch

%if %{with tests}
BuildRequires:  python3dist(pytest)
%if %{with pytest_xdist}
BuildRequires:  python3dist(pytest-xdist)
%endif
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(pip)
BuildRequires:  python3dist(setuptools)
%if %{with tox_tests}
BuildRequires:  python3dist(tox-current-env) >= 0.0.6
%endif
BuildRequires:  python3dist(wheel)
%endif

# We build on top of those:
BuildRequires:  python-rpm-macros
BuildRequires:  python-srpm-macros
BuildRequires:  python3-rpm-macros
Requires:       python-rpm-macros
Requires:       python-srpm-macros
Requires:       python3-rpm-macros
Requires:       pyproject-srpm-macros = %{version}-%{release}

%if ! %{with bootstrap}
# Mageia specific, do not remove before Mageia 10
# BuildRequires hard coded into %%pyproject_buildrequires
# for pyproject.toml
Requires:       python3-pip
Requires:       python3-packaging
# for setup.py
Requires:       python3-setuptools
Requires:       python3-wheel
%endif

# We use the following tools outside of coreutils
Requires:       findutils
Requires:       sed

# This package requires the %%generate_buildrequires functionality.
# It has been introduced in RPM 4.15 (4.14.90 is the alpha of 4.15).
# What we need is rpmlib(DynamicBuildRequires), but that is impossible to (Build)Require.
# Also, we need to avoid 4.19.90..4.19.91-7 due to rhbz#2284187
Requires:       rpm-build >= 4.14.90
BuildRequires:  rpm-build >= 4.14.90

%description
These macros allow projects that follow the Python packaging specifications
to be packaged as RPMs.

They work for:

* traditional Setuptools-based projects that use the setup.py file,
* newer Setuptools-based projects that have a setup.cfg file,
* general Python projects that use the PEP 517 pyproject.toml file
  (which allows using any build system, such as setuptools, flit or poetry).

These macros replace %%py3_build and %%py3_install,
which only work with setup.py.


%package -n pyproject-srpm-macros
Summary:        Minimal implementation of pyproject_buildrequires rpm macro
Requires:       pyproject-rpm-macros = %{version}-%{release}
Requires:       rpm-build >= 4.14.90

%description -n pyproject-srpm-macros
This package contains a minimal implementation of %%pyproject_buildrequires.
When used in %%generate_buildrequires, it will generate BuildRequires
for pyproject-rpm-macros. When both packages are installed, the full version
takes precedence.


%prep
# Not strictly necessary but allows working on file names instead
# of source numbers in install section
%setup -c -T
cp -p %{sources} .

%autopatch -p1

%generate_buildrequires
# nothing to do, this is here just to assert we have that functionality

%build
# nothing to do, sources are not buildable

%install
mkdir -p %{buildroot}%{_rpmmacrodir}
mkdir -p %{buildroot}%{_rpmconfigdir}/redhat
install -pm 644 macros.pyproject %{buildroot}%{_rpmmacrodir}/
install -pm 644 macros.aaa-pyproject-srpm %{buildroot}%{_rpmmacrodir}/
install -pm 644 pyproject_buildrequires.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_convert.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_save_files.py  %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_preprocess_record.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_construct_toxenv.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_requirements_txt.py %{buildroot}%{_rpmconfigdir}/redhat/
install -pm 644 pyproject_wheel.py %{buildroot}%{_rpmconfigdir}/redhat/


%if %{with tests}
%check
export HOSTNAME="rpmbuild"  # to speedup tox in network-less mock, see rhbz#1856356
%pytest -vv --doctest-modules %{?with_pytest_xdist:-n auto} %{!?with_tox_tests:-k "not tox"}

# brp-compress is provided as an argument to get the right directory macro expansion
%{python3} compare_mandata.py -f %{_rpmconfigdir}/brp-compress
%endif


%files
%{_rpmmacrodir}/macros.pyproject
%{_rpmconfigdir}/redhat/pyproject_buildrequires.py
%{_rpmconfigdir}/redhat/pyproject_convert.py
%{_rpmconfigdir}/redhat/pyproject_save_files.py
%{_rpmconfigdir}/redhat/pyproject_preprocess_record.py
%{_rpmconfigdir}/redhat/pyproject_construct_toxenv.py
%{_rpmconfigdir}/redhat/pyproject_requirements_txt.py
%{_rpmconfigdir}/redhat/pyproject_wheel.py

%doc README.md
%license LICENSE

%files -n pyproject-srpm-macros
%{_rpmmacrodir}/macros.aaa-pyproject-srpm
%license LICENSE



%changelog
* Wed Jul 02 2025 umeabot <umeabot> 1.16.3-4.mga10
+ Revision: 2236095
- Mageia 10 Mass Rebuild

* Thu Feb 20 2025 wally <wally> 1.16.3-3.mga10
+ Revision: 2150165
- non-bootstrap build for python3.13

* Wed Feb 19 2025 neoclust <neoclust> 1.16.3-2.mga10
+ Revision: 2149848
- Rebuild in bootstrap mode

* Sat Dec 28 2024 wally <wally> 1.16.3-1.mga10
+ Revision: 2130840
- new version 1.16.3 (from Fedora)

* Mon Sep 02 2024 daviddavid <daviddavid> 1.14.0-3.mga10
+ Revision: 2092668
- restore python3-wheel and python3-pip as runtime dependencies

* Tue Aug 27 2024 wally <wally> 1.14.0-2.mga10
+ Revision: 2091787
- fix fuckups after blind sync with Fedora!

* Tue Aug 27 2024 neoclust <neoclust> 1.14.0-1.mga10
+ Revision: 2091778
- New version 1.14.0

* Thu Jun 27 2024 papoteur <papoteur> 1.12.1-1.mga10
+ Revision: 2077214
- rebuild for python 3.12
- new version 1.12.1

* Wed Feb 21 2024 wally <wally> 1.11.0-3.mga10
+ Revision: 2042908
- update req loosening patch

* Sat Jan 20 2024 wally <wally> 1.11.0-2.mga10
+ Revision: 2032556
- fix typos in req loosening patch

* Sat Jan 06 2024 wally <wally> 1.11.0-1.mga10
+ Revision: 2028281
- new version 1.11.0

* Wed Jan 03 2024 wally <wally> 1.5.0-26.mga10
+ Revision: 2027251
- update req loosening patch

* Mon Jan 01 2024 wally <wally> 1.5.0-25.mga10
+ Revision: 2025348
- disable '==1.0' req loosening for now
- update reqs loosening regexp

* Wed Dec 27 2023 wally <wally> 1.5.0-24.mga10
+ Revision: 2022229
- update req loosening patch

* Mon Dec 25 2023 wally <wally> 1.5.0-23.mga10
+ Revision: 2021403
- update loosening patch

* Mon Dec 25 2023 wally <wally> 1.5.0-22.mga10
+ Revision: 2021398
- rework reqs loosening patch and add a couple of more cases

* Mon Dec 25 2023 wally <wally> 1.5.0-21.mga10
+ Revision: 2021161
- update reqs loosening patch

* Fri Dec 22 2023 wally <wally> 1.5.0-20.mga10
+ Revision: 2020848
- rebuild due to BS issues

* Thu Dec 21 2023 wally <wally> 1.5.0-19.mga10
+ Revision: 2020799
- update reqs loosening patch

* Tue Dec 19 2023 wally <wally> 1.5.0-18.mga10
+ Revision: 2019733
- update reqs loosening patch

* Sun Dec 10 2023 wally <wally> 1.5.0-17.mga10
+ Revision: 2016940
- update deps loosening regexps

* Sun Dec 10 2023 wally <wally> 1.5.0-16.mga10
+ Revision: 2016853
- add new dep loosening case

* Sun Dec 10 2023 wally <wally> 1.5.0-15.mga10
+ Revision: 2016826
- update deps loosening regex

* Sat Dec 09 2023 wally <wally> 1.5.0-14.mga10
+ Revision: 2016395
- loosen deps also from setup.py

* Sat Dec 09 2023 wally <wally> 1.5.0-13.mga10
+ Revision: 2016227
- add one more dep loosening case

* Sat Dec 09 2023 wally <wally> 1.5.0-12.mga10
+ Revision: 2016102
- add patch to loosen build time generated buildrequires automatic

* Thu Dec 07 2023 wally <wally> 1.5.0-11.mga10
+ Revision: 2014745
- non-bootstrap build for py3.12 update

* Thu Dec 07 2023 wally <wally> 1.5.0-10.mga10
+ Revision: 2014708
- no need to pull tomli with python >= 3.11

* Thu Dec 07 2023 wally <wally> 1.5.0-9.mga10
+ Revision: 2014636
- bootstrap build for py3.12 update
- drop tomli reqs

* Thu Dec 07 2023 wally <wally> 1.5.0-8.mga10
+ Revision: 2014410
- bootstrap build for py3.12 update

* Wed Dec 06 2023 wally <wally> 1.5.0-7.mga10
+ Revision: 2013566
- sync with Fedora, but keep the version untouched for now

* Tue Dec 05 2023 wally <wally> 1.5.0-6.mga10
+ Revision: 2013461
- make pyproject_buildrequires.py to use tomli
- add bcond for bootstrapping

* Sun Dec 03 2023 wally <wally> 1.5.0-5.mga10
+ Revision: 2012869
- switch requires also to tomli

* Sun Dec 03 2023 wally <wally> 1.5.0-4.mga10
+ Revision: 2012864
- switch to tomli

* Fri Jan 20 2023 wally <wally> 1.5.0-3.mga9
+ Revision: 1934555
- continue hard coding requires to not break autobuilds

* Fri Jan 20 2023 wally <wally> 1.5.0-2.mga9
+ Revision: 1934516
- stop hard coding requires
- add patch to skip boolean deps on mageia

* Sun Jan 01 2023 guillomovitch <guillomovitch> 1.5.0-1.mga9
+ Revision: 1928593
- new version 1.5.0

* Mon Sep 05 2022 wally <wally> 1.3.3-2.mga9
+ Revision: 1883993
- restore requires mistakenly removed in r1883939

* Sun Sep 04 2022 neoclust <neoclust> 1.3.3-1.mga9
+ Revision: 1883940
- New version 1.3.3
+ wally <wally>
- enable tests again

* Fri Aug 05 2022 wally <wally> 1.3.2-7.mga9
+ Revision: 1875439
- disable tests to bootstrap pkg
- fix typo in requires

* Fri Aug 05 2022 wally <wally> 1.3.2-6.mga9
+ Revision: 1875425
- pull some pkgs hardcoded as BRs in %%pyproject_buildrequires (as iurt doesn't handle dynamic BRs)

* Sun Jul 03 2022 papoteur <papoteur> 1.3.2-5.mga9
+ Revision: 1867198
- Fix requires for find

* Sun Jul 03 2022 papoteur <papoteur> 1.3.2-4.mga9
+ Revision: 1867188
- Fix BR

* Fri Jul 01 2022 joequant <joequant> 1.3.2-3.mga9
+ Revision: 1866919
- more syncing

* Fri Jul 01 2022 joequant <joequant> 1.3.2-2.mga9
+ Revision: 1866906
- fix rpm macros

* Fri Jul 01 2022 joequant <joequant> 1.3.2-1.mga9
+ Revision: 1866901
- update to 1.3.2

* Mon Apr 04 2022 guillomovitch <guillomovitch> 1.0.1-1.mga9
+ Revision: 1843895
- new version 1.0.1

* Tue Mar 22 2022 guillomovitch <guillomovitch> 1.0.0-1.mga9
+ Revision: 1816769
- new version 1.0.0

* Mon Mar 21 2022 umeabot <umeabot> 0-51.mga9
+ Revision: 1816063
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 0-50.mga9
+ Revision: 1771789
- disable bootstrap build

* Sat Feb 05 2022 wally <wally> 0-49.mga9
+ Revision: 1771626
- bootstrap build for python 3.10

* Sat Feb 05 2022 wally <wally> 0-48.mga9
+ Revision: 1771622
- rebuild without tests for python 3.10

* Wed Sep 01 2021 wally <wally> 0-47.mga9
+ Revision: 1743962
- add more requires until BS supports dynamic buildrequires

* Sun Aug 22 2021 guillomovitch <guillomovitch> 0-46.mga9
+ Revision: 1742379
- sync with Fedora
- use same package release number as Fedora, as there is no upstream version yet
- enable tests

* Sat Mar 13 2021 wally <wally> 0-7.mga9
+ Revision: 1702198
- sync with Fedora

* Wed Oct 07 2020 wally <wally> 0-6.mga8
+ Revision: 1632608
- require python3dist(wheel)

* Wed Oct 07 2020 wally <wally> 0-5.mga8
+ Revision: 1632603
- require python3dist(packaging) and python3dist(pip) >= 19

* Wed Oct 07 2020 wally <wally> 0-4.mga8
+ Revision: 1632583
- sync with Fedora

* Wed May 20 2020 joequant <joequant> 0-3.mga8
+ Revision: 1586290
- rebuild

* Tue May 19 2020 joequant <joequant> 0-2.mga8
+ Revision: 1586099
- redo to remove complex requires

* Mon May 18 2020 joequant <joequant> 0-1.mga8
+ Revision: 1586090
- imported package pyproject-rpm-macros

